##
##  node-svm.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2019 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_svm      2.1.9
%define       V_svm_snap 20190106

#   package information
Name:         node-svm
Summary:      Node Bindings to LibSVM
URL:          https://github.com/nicolaspanel/node-svm/tree/master
Vendor:       Nicolas Panel
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Algorithm
License:      MIT
Version:      %{V_svm}
Release:      20190106

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/node-svm/node-svm-%{V_svm}-%{V_svm_snap}.tar.xz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, gcc::with_cxx = yes, npm
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  node
PreReq:       node

%description
    This is a Node.js binding for LibSVM, the Support Vector Machine
    (SVM) library.

%track
    prog node-svm:release = {
        version   = %{V_svm}
        url       = https://github.com/nicolaspanel/node-svm/releases
        regex     = v(__VER__)\.tar\.gz
    }
    prog node-svm:snapshot = {
        version   = %{V_svm_snap}
        url       = http://download.openpkg.org/components/versioned/node-svm/
        regex     = node-svm-\d+\.\d+\.\d+-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -c

%build
    #   build native parts
    cd node_modules/node-svm
    npm run install

    #   prune source tree
    rm -rf binding.gyp .[a-z]* [A-Z]*
    rm -rf examples src test
    find . -name test -type d -print | xargs rm -rf
    find . -name example -type d -print | xargs rm -rf
    find . -name examples -type d -print | xargs rm -rf
    find . -name ChangeLog -type f -print | xargs rm -f
    find . -name CHANGELOG.md -type f -print | xargs rm -f
    find . -name README.md -type f -print | xargs rm -f
    find . -name README.markdown -type f -print | xargs rm -f
    find . -name Readme.md -type f -print | xargs rm -f
    find . -name .npmignore -type f -print | xargs rm -f
    find . -name .travis.yml -type f -print | xargs rm -f
    find . -name LICENSE -type f -print | xargs rm -f
    find . -name LICENSE.txt -type f -print | xargs rm -f
    find . -name LICENCE -type f -print | xargs rm -f
    find . -name License -type f -print | xargs rm -f
    find . -name AUTHORS -type f -print | xargs rm -f
    find . -name CONTRIBUTING.md -type f -print | xargs rm -f

%install
    #   create installation hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/lib/node/pkg/node-svm/node_modules

    #   install package
    cp -rp node_modules/node-svm/* \
        $RPM_BUILD_ROOT%{l_prefix}/lib/node/pkg/node-svm/
    rm -rf node_modules/node-svm
    cp -rp node_modules/* \
        $RPM_BUILD_ROOT%{l_prefix}/lib/node/pkg/node-svm/node_modules/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

